@@ -217,16 +217,18 @@ def linkcode_resolve(
     fn = relpath(fn, start=dirname(libtmux.__file__))
 
     if "dev" in about["__version__"]:
-        return "{}/blob/master/{}/{}{}".format(
+        return "{}/blob/master/{}/{}/{}{}".format(
             about["__github__"],
+            "src",
             about["__package_name__"],
             fn,
             linespec,
         )
     else:
-        return "{}/blob/v{}/{}/{}{}".format(
+        return "{}/blob/v{}/{}/{}/{}{}".format(
             about["__github__"],
             about["__version__"],
+            "src",
             about["__package_name__"],
             fn,
             linespec,
